@@ -36,6 +36,10 @@
 #include "trig.h"
 #include "wz2100icon.h"
 
+#ifdef HAVE_GLES
+#include "lib/ivis_opengl/eglport.h"
+#endif
+
 #include "lib/widget/scrap.h"
 
 static const enum CURSOR_TYPE cursor_type =
@@ -161,7 +165,9 @@ void frameSetCursor(CURSOR cur)
 	//If we are already using this cursor then  return
 	if (cur != currentCursor)
         {
+#ifndef HAVE_GLES
 		SDL_SetCursor(aCursors[cur]);
+#endif
 		currentCursor = cur;
         }
 }
@@ -233,12 +239,16 @@ bool frameInitialise(
 	uint32_t bmask = 0x00ff0000;
 	uint32_t amask = 0xff000000;
 #endif
-
 	if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) != 0)
 	{
 		debug( LOG_ERROR, "Error: Could not initialise SDL (%s).\n", SDL_GetError() );
 		return false;
 	}
+#ifdef HAVE_GLES
+       	if (!EGL_Open())
+		exit(1);
+#endif
+
 
 	SDL_WM_SetIcon(SDL_CreateRGBSurfaceFrom((void*)wz2100icon.pixel_data, wz2100icon.width, wz2100icon.height, wz2100icon.bytes_per_pixel * 8,
 	                                        wz2100icon.width * wz2100icon.bytes_per_pixel, rmask, gmask, bmask, amask), NULL);
@@ -313,6 +323,9 @@ void frameShutDown(void)
 	/* Free all cursors */
 	freeCursors();
 
+#if defined(HAVE_GLES)
+	EGL_Destroy();
+#endif
 	/* Destroy the Application window */
 	SDL_Quit();
 
