@@ -20,7 +20,7 @@
 #ifndef __INCLUDED_LIB_FRAMEWORK_LEXER_INPUT_H__
 #define __INCLUDED_LIB_FRAMEWORK_LEXER_INPUT_H__
 
-#include <physfs.h>
+#include "physfs.h"
 
 typedef struct
 {
