@@ -77,14 +77,16 @@ void pie_BeginLighting(const Vector3f * light)
 	const float specular[4] = {1.0f, 1.0f, 1.0f, 1.0f};
 
 	glLightModelfv(GL_LIGHT_MODEL_AMBIENT, zero);
+#ifndef HAVE_GLES
 	glLightModeli(GL_LIGHT_MODEL_LOCAL_VIEWER, GL_FALSE);
+#endif
 	glLightfv(GL_LIGHT0, GL_POSITION, pos);
 	glLightfv(GL_LIGHT0, GL_AMBIENT, ambient);
 	glLightfv(GL_LIGHT0, GL_DIFFUSE, diffuse);
 	glLightfv(GL_LIGHT0, GL_SPECULAR, specular);
 	glEnable(GL_LIGHT0);
 
-//	lighting = true;
+	lighting = true;
 	shadows = true;
 }
 
@@ -135,6 +137,10 @@ static void pie_Draw3DShape2(iIMDShape *shape, int frame, PIELIGHT colour, WZ_DE
 
 	pie_SetAlphaTest(true);
 
+#ifdef HAVE_GLES
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+#endif
 	/* Set tranlucency */
 	if (pieFlag & pie_ADDITIVE)
 	{ //Assume also translucent
@@ -210,7 +216,7 @@ static void pie_Draw3DShape2(iIMDShape *shape, int frame, PIELIGHT colour, WZ_DE
 		pPixels->z = pVertices->z;
 	}
 
-	glColor4ubv(colour.vector);	// Only need to set once for entire model
+	glColor4ub(colour.vector[0],colour.vector[1],colour.vector[2],colour.vector[3]);	// Only need to set once for entire model
 
 	for (pPolys = shape->polys;
 			pPolys < shape->polys + shape->npolys;
@@ -257,6 +263,7 @@ static void pie_Draw3DShape2(iIMDShape *shape, int frame, PIELIGHT colour, WZ_DE
 			glDisable(GL_CULL_FACE);
 		}
 
+#ifndef HAVE_GLES
 		glBegin(GL_TRIANGLE_FAN);
 
 		if (light)
@@ -271,6 +278,15 @@ static void pie_Draw3DShape2(iIMDShape *shape, int frame, PIELIGHT colour, WZ_DE
 		}
 
 		glEnd();
+#else
+		glVertexPointer(3, GL_FLOAT, 0, (GLfloat*)vertexCoords);
+		glTexCoordPointer(2, GL_FLOAT, 0, (GLfloat*)texCoords);
+		if (light)
+		{
+			glNormal3f(pPolys->normal.x, pPolys->normal.y, pPolys->normal.z);
+		}
+		glDrawArrays(GL_TRIANGLE_FAN, 0, pPolys->npnts);
+#endif
 
 		if (pPolys->flags & PIE_NO_CULL)
 		{
@@ -288,6 +304,10 @@ static void pie_Draw3DShape2(iIMDShape *shape, int frame, PIELIGHT colour, WZ_DE
 		glDisable(GL_LIGHTING);
 		glDisable(GL_NORMALIZE);
 	}
+#ifdef HAVE_GLES
+	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	glDisableClientState(GL_VERTEX_ARRAY);
+#endif
 }
 
 /// returns true if the edges are adjacent
@@ -447,6 +467,7 @@ static void pie_DrawShadow(iIMDShape *shape, int flag, int flag_data, Vector3f*
 	}
 
 	// draw the shadow volume
+#ifndef HAVE_GLES
 	glBegin(GL_QUADS);
 	for(i=0;i<edge_count;i++)
 	{
@@ -462,8 +483,26 @@ static void pie_DrawShadow(iIMDShape *shape, int flag, int flag_data, Vector3f*
 		glVertex3f(pVertices[a].x, scale_y(pVertices[a].y, flag, flag_data), pVertices[a].z);
 	}
 	glEnd();
+#else
+	glEnableClientState(GL_VERTEX_ARRAY);
+	for(i=0;i<edge_count;i++) {
+		int a = drawlist[i].from, b = drawlist[i].to;
+		if (a < 0)
+		{
+			continue;
+		}
+		GLfloat vtx1[] = {	pVertices[b].x, scale_y(pVertices[b].y, flag, flag_data), pVertices[b].z,
+					pVertices[b].x+light->x, scale_y(pVertices[b].y, flag, flag_data)+light->y, pVertices[b].z+light->z,
+					pVertices[a].x+light->x, scale_y(pVertices[a].y, flag, flag_data)+light->y, pVertices[a].z+light->z,
+					pVertices[a].x, scale_y(pVertices[a].y, flag, flag_data), pVertices[a].z}; 
+		glVertexPointer(3, GL_FLOAT, 0, vtx1);
+		glDrawArrays(GL_TRIANGLE_FAN,0,4);
+	}
+	glDisableClientState(GL_VERTEX_ARRAY);
+#endif
 
 #ifdef SHOW_SHADOW_EDGES
+#ifndef HAVE_GLES
 	glDisable(GL_DEPTH_TEST);
 	glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 
@@ -483,6 +522,28 @@ static void pie_DrawShadow(iIMDShape *shape, int flag, int flag_data, Vector3f*
 	glEnd();
 	glColorMask(GL_FALSE, GL_FALSE, GL_FALSE, GL_FALSE);
 	glEnable(GL_DEPTH_TEST);
+#else
+        glDisable(GL_DEPTH_TEST);
+        glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
+
+        glColor4ub(0xFF, 0, 0, 0xFF);
+        glEnableClientState(GL_VERTEX_ARRAY);
+        for(i = 0; i < edge_count; i++)
+        {
+                int a = drawlist[i].from, b = drawlist[i].to;
+                if (a < 0)
+                {
+                	continue;
+                }
+                GLfloat vtx1[] = { pVertices[b].x, scale_y(pVertices[b].y, flag, flag_data), pVertices[b].z,
+                                   pVertices[a].x, scale_y(pVertices[a].y, flag, flag_data), pVertices[a].z};
+                glVertexPointer(2, GL_FLOAT, 0, vtx1);
+                glDrawArrays(GL_LINES, 0, 2);
+        }
+        glDisableClientState(GL_VERTEX_ARRAY);
+        glColorMask(GL_FALSE, GL_FALSE, GL_FALSE, GL_FALSE);
+        glEnable(GL_DEPTH_TEST);
+#endif
 #endif
 }
 
@@ -708,12 +769,20 @@ static void pie_DrawShadows(void)
 	pie_PerspectiveEnd();
 	glLoadIdentity();
 	glDisable(GL_DEPTH_TEST);
+#ifndef HAVE_GLES
 	glBegin(GL_TRIANGLE_STRIP);
 		glVertex2f(0, 0);
 		glVertex2f(width, 0);
 		glVertex2f(0, height);
 		glVertex2f(width, height);
 	glEnd();
+#else
+	GLfloat vtx2[] = {0, 0,		width, 0,	0, height,	width, height};
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glVertexPointer(2, GL_FLOAT, 0, vtx2);
+	glDrawArrays(GL_TRIANGLE_STRIP,0,4);
+	glDisableClientState(GL_VERTEX_ARRAY);
+#endif
 	pie_PerspectiveBegin();
 
 	glDisable(GL_BLEND);
@@ -769,8 +838,9 @@ void pie_DrawImage(const PIEIMAGE *image, const PIERECT *dest)
 
 	pie_SetTexturePage(image->texPage);
 
-	glColor4ubv(colour.vector);
+	glColor4ub(colour.vector[0], colour.vector[1], colour.vector[2], colour.vector[3]);
 
+#if 0 //!defined(HAVE_GLES)
 	glBegin(GL_TRIANGLE_STRIP);
 		//set up 4 pie verts
 		glTexCoord2f(image->tu, image->tv);
@@ -785,6 +855,17 @@ void pie_DrawImage(const PIEIMAGE *image, const PIERECT *dest)
 		glTexCoord2f(image->tu + image->tw, image->tv + image->th);
 		glVertex2f(dest->x + dest->w, dest->y + dest->h);
 	glEnd();
+#else
+	GLfloat vtx[] = {dest->x, dest->y,	dest->x + dest->w, dest->y,		dest->x, dest->y + dest->h,		dest->x + dest->w, dest->y + dest->h};
+	GLfloat tex[] = {image->tu, image->tv,	image->tu + image->tw, image->tv,	image->tu, image->tv + image->th,	image->tu + image->tw, image->tv + image->th};
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+	glVertexPointer(2, GL_FLOAT, 0, vtx);
+	glTexCoordPointer(2, GL_FLOAT, 0, tex);
+	glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
+	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	glDisableClientState(GL_VERTEX_ARRAY);
+#endif
 }
 
 static inline void pie_ClearArrays(void)
@@ -885,6 +966,7 @@ void pie_DrawWaterTriangle(const TERRAIN_VERTEX *aVrts)
 	/* Since this is only used from within source for the terrain draw - we can backface cull the polygons. */
 	tileCount++;
 
+#ifndef HAVE_GLES
 	glBegin(GL_TRIANGLE_FAN);
 		for ( i = 0; i < 3; i++ )
 		{
@@ -893,6 +975,26 @@ void pie_DrawWaterTriangle(const TERRAIN_VERTEX *aVrts)
 			glVertex3f( aVrts[i].pos.x, aVrts[i].pos.y, aVrts[i].pos.z );
 		}
 	glEnd();
+#else
+	GLfloat vtx[] = {	aVrts[0].pos.x, aVrts[0].pos.y, aVrts[0].pos.z,		aVrts[1].pos.x, aVrts[1].pos.y, aVrts[1].pos.z,
+				aVrts[2].pos.x, aVrts[2].pos.y, aVrts[2].pos.z,		aVrts[3].pos.x, aVrts[3].pos.y, aVrts[3].pos.z};
+	GLfloat tex[] = {	aVrts[0].u, aVrts[0].v,					aVrts[1].u, aVrts[1].v,
+				aVrts[2].u, aVrts[2].v,					aVrts[3].u, aVrts[3].v};
+	GLfloat col[] = {	aVrts[0].light.vector[0], aVrts[0].light.vector[1], aVrts[0].light.vector[2], aVrts[0].light.vector[3],
+				aVrts[1].light.vector[0], aVrts[1].light.vector[1], aVrts[1].light.vector[2], aVrts[1].light.vector[3],
+				aVrts[2].light.vector[0], aVrts[2].light.vector[1], aVrts[2].light.vector[2], aVrts[2].light.vector[3],
+				aVrts[3].light.vector[0], aVrts[3].light.vector[1], aVrts[3].light.vector[2], aVrts[3].light.vector[3]};
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+	glEnableClientState(GL_COLOR_ARRAY);
+	glVertexPointer(3, GL_FLOAT, 0, vtx);
+	glColorPointer(4, GL_FLOAT, 0, col);
+	glTexCoordPointer(2, GL_FLOAT, 0, tex);
+	glDrawArrays(GL_TRIANGLE_FAN,0,4);
+	glDisableClientState(GL_COLOR_ARRAY);
+	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	glDisableClientState(GL_VERTEX_ARRAY);
+#endif
 }
 
 void pie_GetResetCounts(unsigned int* pPieCount, unsigned int* pTileCount, unsigned int* pPolyCount, unsigned int* pStateCount)
