@@ -34,7 +34,11 @@
  *	Local Definitions
  */
 /***************************************************************************/
-
+#ifdef HAVE_GLES
+#define glDepthRange glDepthRangef
+#define glOrtho      glOrthof
+#define glFrustum    glFrustumf
+#endif
 #define MATRIX_MAX 8
 #define ONE_PERCENT 4096/100
 
