@@ -26,7 +26,11 @@
 
 #include <SDL.h>
 #include <SDL_mouse.h>
+#ifndef HAVE_GLES
 #include <SDL_opengl.h>
+#else
+#include <GLES/glues.h>
+#endif
 
 #include "lib/ivis_common/piestate.h"
 #include "lib/ivis_common/piedef.h"
@@ -125,7 +129,11 @@ void pie_SetFogStatus(BOOL val)
 				fog_colour[2] = fog.byte.b/255.0f;
 				fog_colour[3] = fog.byte.a/255.0f;
 
+#ifndef HAVE_GLES
 				glFogi(GL_FOG_MODE, GL_LINEAR);
+#else
+				glFogf(GL_FOG_MODE, GL_LINEAR);
+#endif
 				glFogfv(GL_FOG_COLOR, fog_colour);
 				glFogf(GL_FOG_DENSITY, 0.35f);
 				glHint(GL_FOG_HINT, GL_DONT_CARE);
@@ -249,6 +257,7 @@ void pie_DrawMouse(unsigned int X, unsigned int Y)
 void pie_ShowMouse(bool visible)
 {
 	MouseVisible = visible;
+#ifndef PANDORA
 	if (MouseVisible && !ColouredMouse)
 	{
 		SDL_ShowCursor(SDL_ENABLE);
@@ -257,6 +266,7 @@ void pie_ShowMouse(bool visible)
 	{
 		SDL_ShowCursor(SDL_DISABLE);
 	}
+#endif
 }
 
 bool _glerrors(const char *function, const char *file, int line)
