@@ -42,6 +42,12 @@
 
 #if defined(WZ_OS_MAC)
 #include <OpenGL/glu.h>
+#elif defined(HAVE_GLES)
+#include <GLES/gl.h>
+#include <GLES/glues.h>
+#include "lib/ivis_opengl/eglport.h"
+#define GL_CLAMP     GL_CLAMP_TO_EDGE
+#define glOrtho      glOrthof
 #else
 #include <GL/glu.h>
 #endif
@@ -68,6 +74,13 @@ static Vector2i player_pos[MAX_PLAYERS];
 static BOOL mappreview = false;
 static char mapname[256];
 
+#ifdef HAVE_GLES
+// We need to hide the system cursor on the Pandora as it messes up the 3d display
+// and just disabling it can cause cursor drift
+static uint8_t hiddenCursorData = 0;
+static SDL_Cursor *hiddenCursor = NULL;
+#endif
+
 /* Initialise the double buffered display */
 bool screenInitialise(
 			UDWORD		width,		// Display width
@@ -80,6 +93,12 @@ bool screenInitialise(
 	int video_flags = 0;
 	int bpp = 0, value;
 
+#ifdef PANDORA
+	// HACK: Extract FSAA from bitDepth
+	UDWORD fsaa = bitDepth >> 8;
+	bitDepth -= fsaa << 8;
+#endif
+
 	// Fetch the video info.
 	const SDL_VideoInfo* video_info = SDL_GetVideoInfo();
 
@@ -129,11 +148,13 @@ bool screenInitialise(
 		video_flags |= SDL_FULLSCREEN;
 	}
 
+#ifndef HAVE_GLES
 	// Set the double buffer OpenGL attribute.
 	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
 
 	// Enable vsync if requested by the user
 	SDL_GL_SetAttribute(SDL_GL_SWAP_CONTROL, vsync);
+#endif
 
 	bpp = SDL_VideoModeOK(width, height, bitDepth, video_flags);
 	if (!bpp)
@@ -141,6 +162,7 @@ bool screenInitialise(
 		debug(LOG_ERROR, "Video mode %dx%d@%dbpp is not supported!", width, height, bitDepth);
 		return false;
 	}
+#ifndef HAVE_GLES
 	switch (bpp)
 	{
 		case 32:
@@ -170,6 +192,9 @@ bool screenInitialise(
 			exit(1);
 			break;
 	}
+#else
+	video_flags = SDL_SWSURFACE | SDL_FULLSCREEN;
+#endif
 
 	screen = SDL_SetVideoMode(width, height, bpp, video_flags);
 	if (!screen)
@@ -177,6 +202,7 @@ bool screenInitialise(
 		debug(LOG_ERROR, "SDL_SetVideoMode failed (%s).", SDL_GetError());
 		return false;
 	}
+#ifndef HAVE_GLES
 	if (SDL_GL_GetAttribute(SDL_GL_DOUBLEBUFFER, &value) == -1)
 	{
 		debug(LOG_FATAL, "OpenGL initialization did not give double buffering!");
@@ -184,7 +210,11 @@ bool screenInitialise(
 		exit(1);
 	}
 	// Note that no initialisation of GLee is required, since this is handled automatically.
-
+#else
+	EGL_Init(fsaa);
+       	hiddenCursor = SDL_CreateCursor(&hiddenCursorData, &hiddenCursorData, 8, 1, 0, 0);
+       	SDL_SetCursor(hiddenCursor);
+#endif
 	{
 		char buf[256];
 
@@ -244,7 +274,11 @@ bool screenInitialise(
 	glEnable(GL_CULL_FACE);
 
 	glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
+#ifndef HAVE_GLES
 	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_ACCUM_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+#else
+	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+#endif
 
 	glErrors();
 	return true;
@@ -257,8 +291,16 @@ void screenShutDown(void)
 	if (screen != NULL)
 	{
 		glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
+#ifndef HAVE_GLES
 		glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_ACCUM_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+#else
+		glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+#endif
 		glFlush();
+#ifdef HAVE_GLES
+		SDL_SetCursor(NULL);
+		SDL_FreeCursor(hiddenCursor);
+#endif
 		SDL_FreeSurface(screen);
 		screen = NULL;
 	}
@@ -289,7 +331,7 @@ void screen_SetBackDropFromFile(const char* filename)
 				glGenTextures(1, &backDropTexture);
 
 			glBindTexture(GL_TEXTURE_2D, backDropTexture);
-			glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA,
+			glTexImage2D(GL_TEXTURE_2D, 0, iV_getPixelFormat(&image),
 					image.width, image.height,
 					0, iV_getPixelFormat(&image), GL_UNSIGNED_BYTE, image.bmp);
 			glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
@@ -374,7 +416,7 @@ void screen_Upload(const char *newBackDropBmp, BOOL preview)
 
 	glEnable(GL_TEXTURE_2D);
 	glBindTexture(GL_TEXTURE_2D, backDropTexture);
-	glColor3f(1, 1, 1);
+	glColor4f(1, 1, 1, 1);
 
 	if (preview)
 	{
@@ -406,6 +448,7 @@ void screen_Upload(const char *newBackDropBmp, BOOL preview)
 	tx *= 256;
 	ty *= 256;
 
+#ifndef HAVE_GLES
 	glBegin(GL_TRIANGLE_STRIP);
 		glTexCoord2f(0, 0);
 		glVertex2f(x1, y1);
@@ -416,6 +459,21 @@ void screen_Upload(const char *newBackDropBmp, BOOL preview)
 		glTexCoord2f(tx, ty);
 		glVertex2f(x2, y2);
 	glEnd();
+#else
+	{
+	GLfloat vtx1[] = {x1, y1,	x2, y1,		x1, y2,		x2, y2};
+	GLfloat tex1[] = {0, 0,		tx, 0,		0, ty,		tx, ty};
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+ 
+	glVertexPointer(2, GL_FLOAT, 0, vtx1);
+	glTexCoordPointer(2, GL_FLOAT, 0, tex1);
+	glDrawArrays(GL_TRIANGLE_STRIP,0,4);
+ 
+	glDisableClientState(GL_VERTEX_ARRAY);
+	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	}
+#endif
 
 	if (preview)
 	{
