@@ -23,6 +23,11 @@
 
 #if defined(WZ_OS_MAC)
 #include <OpenGL/glu.h>
+#elif defined(HAVE_GLES)
+#include <GLES/gl.h>
+#include "eglport.h"
+#include <GLES/glues.h>
+#define GL_CLAMP     GL_CLAMP_TO_EDGE
 #else
 #include <GL/glu.h>
 #endif
@@ -123,7 +128,7 @@ int pie_AddTexPage(iV_Image *s, const char* filename, int slot, int maxTextureSi
 		if (maxTextureSize)
 		{
 			// this is a 3D texture, use texture compression
-			gluBuild2DMipmaps(GL_TEXTURE_2D, wz_texture_compression, width, height, iV_getPixelFormat(s), GL_UNSIGNED_BYTE, bmp);
+		  gluBuild2DMipmaps(GL_TEXTURE_2D, wz_texture_compression, width, height, iV_getPixelFormat(s), GL_UNSIGNED_BYTE, bmp);
 		}
 		else
 		{
