@@ -32,13 +32,19 @@
 #include "lib/ivis_common/ivispatch.h"
 #include "lib/ivis_common/textdraw.h"
 #include "lib/ivis_common/bitimage.h"
-
+#ifdef HAVE_FONTSTASH
+#include "lib/ivis_opengl/fontstash.h"
+#else
+#ifndef HAVE_FTGLES
 #ifdef WZ_OS_MAC
 # include <QuesoGLC/glc.h>
 #else
 # include <GL/glc.h>
 #endif
-
+#else
+#include <FTGL/ftgl.h>
+#endif
+#endif
 static char font_family[128];
 static char font_face_regular[128];
 static char font_face_bold[128];
@@ -47,9 +53,20 @@ static float font_size = 12.f;
 // Contains the font color in the following order: red, green, blue, alpha
 static float font_colour[4] = {1.f, 1.f, 1.f, 1.f};
 
+#if defined(HAVE_FONTSTASH)
+struct sth_stash* stash;
+int st_regular, st_bold, st_current;
+#elif defined(HAVE_FTGLES)
+FTGLfont *ftFontRegular;
+FTGLfont *ftFontLarge;
+FTGLfont *ftFontSmall;
+FTGLfont *ftFontScaled;
+FTGLfont *ftFontCurrent;
+#else
 static GLint _glcContext = 0;
 static GLint _glcFont_Regular = 0;
 static GLint _glcFont_Bold = 0;
+#endif
 
 /***************************************************************************/
 /*
@@ -59,6 +76,7 @@ static GLint _glcFont_Bold = 0;
 
 void iV_font(const char *fontName, const char *fontFace, const char *fontFaceBold)
 {
+#if !defined(HAVE_FTGLES) && !defined(HAVE_FONTSTASH)
 	if (_glcContext)
 	{
 		debug(LOG_ERROR, "Cannot change font in running game, yet.");
@@ -76,10 +94,12 @@ void iV_font(const char *fontName, const char *fontFace, const char *fontFaceBol
 	{
 		sstrcpy(font_face_bold, fontFaceBold);
 	}
+#endif
 }
 
 static inline void iV_printFontList(void)
 {
+#if !defined(HAVE_FTGLES) && !defined(HAVE_FONTSTASH)
 	unsigned int i;
 	unsigned int font_count = glcGeti(GLC_CURRENT_FONT_COUNT);
 
@@ -107,10 +127,12 @@ static inline void iV_printFontList(void)
 		sstrcat(prBuffer, glcGetFontFace(font));
 		debug(LOG_NEVER, "%s", prBuffer);
 	}
+#endif
 }
 
 static void iV_initializeGLC(void)
 {
+#if !defined(HAVE_FTGLES) && !defined(HAVE_FONTSTASH)
 	if (_glcContext)
 	{
 		return;
@@ -174,19 +196,44 @@ static void iV_initializeGLC(void)
 	}
 
 	debug(LOG_NEVER, "Finished initializing GLC");
+#endif
 }
 
 void iV_TextInit()
 {
+#if defined(HAVE_FONTSTASH)
+	stash = sth_create(512,512);
+	if (!(st_regular = sth_add_font(stash,"/mnt/utmp/wz2100/share/DejaVuSans.ttf")))
+	  if (!(st_regular = sth_add_font(stash,"DejaVuSans.ttf")))
+	    printf("Cannot load DejaVuSans.ttf\n");
+	if (!(st_bold = sth_add_font(stash,"/mnt/utmp/wz2100/share/DejaVuSans-Bold.ttf")))
+	  if (!(st_bold = sth_add_font(stash,"DejaVuSans-Bold.ttf")))
+	    printf("Cannot load DejaVuSans-Bold.ttf\n");
+	iV_SetFont(font_regular);
+	font_size = 12.0;
+#elif defined(HAVE_FTGLES)
+	ftFontRegular = ftglCreateBufferFont("/mnt/utmp/wz2100/share/DejaVuSans.ttf");
+	ftglSetFontFaceSize(ftFontRegular, 12, 0);
+	ftFontScaled = ftglCreateBufferFont("/mnt/utmp/wz2100/share/DejaVuSans.ttf");
+	ftglSetFontFaceSize(ftFontScaled, 12, 0);
+	ftFontSmall = ftglCreateBufferFont("/mnt/utmp/wz2100/share/DejaVuSans.ttf");
+	ftglSetFontFaceSize(ftFontSmall, 9, 0);
+	ftFontLarge = ftglCreateBufferFont("/mnt/utmp/wz2100/share/DejaVuSans-Bold.ttf");
+	ftglSetFontFaceSize(ftFontLarge, 21, 0);
+	iV_SetFont(font_regular);
+	//printf("errors : %d\n",ftglGetFontError(ftFontLarge));
+#else
 	iV_initializeGLC();
 	iV_SetFont(font_regular);
 #ifdef DEBUG
 	iV_printFontList();
 #endif
+#endif
 }
 
 void iV_TextShutdown()
 {
+#if !defined(HAVE_FTGLES) && !defined(HAVE_FONTSTASH)
 	if (_glcFont_Regular)
 	{
 		glcDeleteFont(_glcFont_Regular);
@@ -203,10 +250,58 @@ void iV_TextShutdown()
 	{
 		glcDeleteContext(_glcContext);
 	}
+#endif
 }
 
 void iV_SetFont(enum iV_fonts FontID)
 {
+#if defined(HAVE_FONTSTASH)
+	switch (FontID)
+	{
+		case font_regular:
+			iV_SetTextSize(12.f);
+			st_current = st_regular;
+			break;
+
+		case font_scaled:
+			iV_SetTextSize(12.f * pie_GetVideoBufferHeight() / 480.f);
+			st_current = st_regular;
+			break;
+
+		case font_large:
+			iV_SetTextSize(21.f);
+			st_current = st_bold;
+			break;
+
+		case font_small:
+			iV_SetTextSize(9.f);
+			st_current = st_regular;
+			break;
+	}
+#elif defined(HAVE_FTGLES)
+	switch (FontID)
+	{
+		case font_regular:
+			ftFontCurrent = ftFontRegular;
+			//printf("Regulars\t\t");
+			break;
+
+		case font_scaled:
+			ftFontCurrent = ftFontScaled;
+			//printf("Scaled\t\t");
+			break;
+
+		case font_large:
+			ftFontCurrent = ftFontLarge;
+			//printf("Large\t\t");
+			break;
+
+		case font_small:
+			ftFontCurrent = ftFontSmall;
+			//printf("Small\t\t");
+			break;
+	}
+#else
 	switch (FontID)
 	{
 		case font_regular:
@@ -229,10 +324,12 @@ void iV_SetFont(enum iV_fonts FontID)
 			glcFont(_glcFont_Regular);
 			break;
 	}
+#endif
 }
 
 static inline float getGLCResolution(void)
 {
+#if !defined(HAVE_FTGLES) && !defined(HAVE_FONTSTASH)
 	float resolution = glcGetf(GLC_RESOLUTION);
 
 	// The default resolution as used by OpenGLC is 72 dpi
@@ -242,34 +339,56 @@ static inline float getGLCResolution(void)
 	}
 
 	return resolution;
+#else
+	return 72.0;
+#endif
 }
 
 static inline float getGLCPixelSize(void)
 {
+#if !defined(HAVE_FTGLES) && !defined(HAVE_FONTSTASH)
 	float pixel_size = font_size * getGLCResolution() / 72.f;
 	return pixel_size;
+#else
+	return 1;
+#endif
 }
 
 static inline float getGLCPointWidth(const float* boundingbox)
 {
+#ifndef HAVE_FTGLES
 	// boundingbox contains: [ xlb ylb xrb yrb xrt yrt xlt ylt ]
 	// l = left; r = right; b = bottom; t = top;
 	float rightTopX = boundingbox[4];
 	float leftTopX = boundingbox[6];
+#else
+	// [ aX aY aZ bX bY bZ ]
+	// a  = lower left near ; b = upper right far
+	float rightTopX = boundingbox[0];
+	float leftTopX = boundingbox[3];
+#endif
 
-	float point_width = rightTopX - leftTopX;
+	float point_width = fabsf(rightTopX - leftTopX);
 
 	return point_width;
 }
 
 static inline float getGLCPointHeight(const float* boundingbox)
 {
+#ifndef HAVE_FTGLES
 	// boundingbox contains: [ xlb ylb xrb yrb xrt yrt xlt ylt ]
 	// l = left; r = right; b = bottom; t = top;
 	float leftBottomY = boundingbox[1];
 	float leftTopY = boundingbox[7];
+#else
+	// [ aX aY aZ bX bY bZ ]
+	// a  = lower left near ; b = upper right far
+	float leftBottomY = boundingbox[1];
+	float leftTopY = boundingbox[4];
+#endif
 
 	float point_height = fabsf(leftTopY - leftBottomY);
+//	float point_height = leftTopY - leftBottomY;
 
 	return point_height;
 }
@@ -286,15 +405,23 @@ unsigned int iV_GetTextWidth(const char* string)
 	float boundingbox[8];
 	float pixel_width, point_width;
 
+#if defined(HAVE_FONTSTASH)
+	float minx=0, maxx=0, miny, maxy;
+	sth_dim_text(stash, st_current, font_size, string, &minx, &miny, &maxx, &maxy);
+	return (unsigned int)(maxx-minx);
+#elif defined(HAVE_FTGLES)
+	ftglGetFontBBox(ftFontCurrent, string, strlen(string), boundingbox);
+#else
 	glcMeasureString(GL_FALSE, string);
 	if (!glcGetStringMetric(GLC_BOUNDS, boundingbox))
 	{
 		debug(LOG_ERROR, "Couldn't retrieve a bounding box for the string \"%s\"", string);
 		return 0;
 	}
-
+#endif
 	point_width = getGLCPointWidth(boundingbox);
 	pixel_width = getGLCPointToPixel(point_width);
+//	printf("Witdh=%f\n", pixel_width);
 	return (unsigned int)pixel_width;
 }
 
@@ -303,6 +430,16 @@ unsigned int iV_GetCountedTextWidth(const char* string, size_t string_length)
 	float boundingbox[8];
 	float pixel_width, point_width;
 
+#if defined(HAVE_FONTSTASH)
+	float minx=0, maxx=0, miny, maxy;
+	char  strng[string_length+1];
+	memcpy(strng, string, string_length);
+	strng[string_length+1] = '\0';
+	sth_dim_text(stash, st_current, font_size, string, &minx, &miny, &maxx, &maxy);
+	return (unsigned int)(maxx-minx);
+#elif defined(HAVE_FTGLES)
+	ftglGetFontBBox(ftFontCurrent, string, string_length, boundingbox);
+#else
 	glcMeasureCountedString(GL_FALSE, string_length, string);
 	if (!glcGetStringMetric(GLC_BOUNDS, boundingbox))
 	{
@@ -310,14 +447,23 @@ unsigned int iV_GetCountedTextWidth(const char* string, size_t string_length)
 		      string, (unsigned int)string_length);
 		return 0;
 	}
+#endif
 
 	point_width = getGLCPointWidth(boundingbox);
 	pixel_width = getGLCPointToPixel(point_width);
+//	printf("Witdh=%f\n", pixel_width);
 	return (unsigned int)pixel_width;
 }
 
 unsigned int iV_GetTextHeight(const char* string)
 {
+#if defined(HAVE_FONTSTASH)
+	float minx, maxx, miny=0, maxy=0;
+	sth_dim_text(stash, st_current, font_size, string, &minx, &miny, &maxx, &maxy);
+	return (unsigned int)(maxy-miny);
+#elif defined(HAVE_FTGLES)
+	return (unsigned int)ftglGetFontLineHeight(ftFontCurrent);
+#else
 	float boundingbox[8];
 	float pixel_height, point_height;
 
@@ -327,10 +473,11 @@ unsigned int iV_GetTextHeight(const char* string)
 		debug(LOG_ERROR, "Couldn't retrieve a bounding box for the string \"%s\"", string);
 		return 0;
 	}
-
 	point_height = getGLCPointHeight(boundingbox);
 	pixel_height = getGLCPointToPixel(point_height);
 	return (unsigned int)pixel_height;
+#endif
+
 }
 
 unsigned int iV_GetCharWidth(uint32_t charCode)
@@ -338,12 +485,19 @@ unsigned int iV_GetCharWidth(uint32_t charCode)
 	float boundingbox[8];
 	float pixel_width, point_width;
 
+#if defined(HAVE_FONTSTASH)
+	float minx=0, maxx=0, miny, maxy;
+	sth_dim_text(stash, st_current, font_size, (char*)&charCode, &minx, &miny, &maxx, &maxy);
+	return (unsigned int)(maxx-minx);
+#elif defined(HAVE_FTGLES)
+	ftglGetFontBBox(ftFontCurrent, (char*)&charCode, 1, boundingbox);
+#else
 	if (!glcGetCharMetric(charCode, GLC_BOUNDS, boundingbox))
 	{
 		debug(LOG_ERROR, "Couldn't retrieve a bounding box for the character code %u", charCode);
 		return 0;
 	}
-
+#endif
 	point_width = getGLCPointWidth(boundingbox);
 	pixel_width = getGLCPointToPixel(point_width);
 	return (unsigned int)pixel_width;
@@ -351,6 +505,13 @@ unsigned int iV_GetCharWidth(uint32_t charCode)
 
 int iV_GetTextLineSize()
 {
+#if defined(HAVE_FONTSTASH)
+	float ret = 0;
+	sth_vmetrics(stash, st_current, font_size, NULL, NULL, &ret);
+	return (int)ret;
+#elif defined(HAVE_FTGLES)
+	return (unsigned int)ftglGetFontLineHeight(ftFontCurrent);
+#else
 	float boundingbox[8];
 	float pixel_height, point_height;
 
@@ -363,10 +524,16 @@ int iV_GetTextLineSize()
 	point_height = getGLCPointHeight(boundingbox);
 	pixel_height = getGLCPointToPixel(point_height);
 	return (unsigned int)pixel_height;
+#endif
 }
 
 static float iV_GetMaxCharBaseY(void)
 {
+#if defined(HAVE_FONTSTASH)
+	return 0.f;
+#elif defined(HAVE_FTGLES)
+	return ftglGetFontAscender(ftFontCurrent);
+#else
 	float base_line[4]; // [ xl yl xr yr ]
 
 	if (!glcGetMaxCharMetric(GLC_BASELINE, base_line))
@@ -376,10 +543,18 @@ static float iV_GetMaxCharBaseY(void)
 	}
 
 	return base_line[1];
+#endif
 }
 
 int iV_GetTextAboveBase(void)
 {
+#if defined(HAVE_FONTSTASH)
+	float ret = 0;
+	sth_vmetrics(stash, st_current, font_size, &ret, NULL, NULL);
+	return (int)-ret;
+#elif defined(HAVE_FTGLES)
+	return (int)-ftglGetFontAscender(ftFontCurrent);
+#else
 	float point_base_y = iV_GetMaxCharBaseY();
 	float point_top_y;
 	float boundingbox[8];
@@ -395,10 +570,18 @@ int iV_GetTextAboveBase(void)
 	point_height = point_base_y - point_top_y;
 	pixel_height = getGLCPointToPixel(point_height);
 	return (int)pixel_height;
+#endif
 }
 
 int iV_GetTextBelowBase(void)
 {
+#if defined(HAVE_FONTSTASH)
+	float ret = 0;
+	sth_vmetrics(stash, st_current, font_size, NULL, &ret, NULL);
+	return (int)ret;
+#elif defined(HAVE_FTGLES)
+	return (int)ftglGetFontDescender(ftFontCurrent);
+#else
 	float point_base_y = iV_GetMaxCharBaseY();
 	float point_bottom_y;
 	float boundingbox[8];
@@ -414,6 +597,7 @@ int iV_GetTextBelowBase(void)
 	point_height = point_bottom_y - point_base_y;
 	pixel_height = getGLCPointToPixel(point_height);
 	return (int)pixel_height;
+#endif
 }
 
 void iV_SetTextColour(PIELIGHT colour)
@@ -637,6 +821,7 @@ void iV_DrawTextRotated(const char* string, float XPos, float YPos, float rotati
 	glMatrixMode(GL_MODELVIEW);
 	glPushMatrix();
 
+#if !defined(HAVE_FONTSTASH)
 	if (rotation != 0.f)
 	{
 		rotation = 360.f - rotation;
@@ -645,12 +830,29 @@ void iV_DrawTextRotated(const char* string, float XPos, float YPos, float rotati
 	glTranslatef(XPos, YPos, 0.f);
 	glRotatef(180.f, 1.f, 0.f, 0.f);
 	glRotatef(rotation, 0.f, 0.f, 1.f);
-	glScalef(font_size, font_size, 0.f);
+#endif
 
-	glColor4fv(font_colour);
+	glColor4f(font_colour[0],font_colour[1],font_colour[2],font_colour[3]);
 
 	glFrontFace(GL_CW);
+#if defined(HAVE_FONTSTASH)
+	glEnable(GL_BLEND);
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	glDisable(GL_TEXTURE_2D);
+	glDisable(GL_DEPTH_TEST);
+	//glMatrixMode(GL_MODELVIEW);
+	glLoadIdentity();
+	glTranslatef(XPos, YPos, 0.f);
+	glRotatef(rotation, 0.f, 0.f, 1.f);
+	sth_begin_draw(stash);
+	sth_draw_text(stash, st_current, font_size, 0, 0, string, NULL);
+	sth_end_draw(stash);
+#elif defined(HAVE_FTGLES)
+	ftglRenderFont(ftFontCurrent, string, 0xffff);
+#else
+	glScalef(font_size, font_size, 0.f);
 	glcRenderString(string);
+#endif
 	glFrontFace(GL_CCW);
 
 	glPopMatrix();
