@@ -81,6 +81,9 @@
 # endif
 #if defined(WZ_OS_MAC)
 #include <OpenGL/glu.h>
+#elif defined(HAVE_GLES)
+#include <GLES/glues.h>
+#define GL_CLAMP     GL_CLAMP_TO_EDGE
 #else
 #include <GL/glu.h>
 #endif
@@ -424,6 +427,7 @@ static void video_write(bool update)
 	// NOTE: 255 * width | height, because texture matrix is set up with a
 	// call to glScalef(1/256.0, 1/256.0, 1) ... so don't blame me. :P
 	glTranslatef(ScrnvidXpos, ScrnvidYpos, 0.0f);
+#if 0 //!defined(HAVE_GLES)
 	glBegin(GL_QUADS);
 	glTexCoord2f(0, 0);
 	glVertex2f(videoX1, videoY1);
@@ -434,7 +438,19 @@ static void video_write(bool update)
 	glTexCoord2f(0, 256 * video_height * height_factor / texture_height);
 	glVertex2f(videoX1, videoY2);				//screenHeight
 	glEnd();
-
+#else
+	{
+	GLfloat vtx1[] = {videoX1, videoY1,	videoX2, videoY1,	videoX2, videoY2,	videoX1, videoY2};
+	GLfloat tex1[] = {0, 0,		256 * video_width / texture_width, 0,	256 * video_width / texture_width, 256 * video_height * height_factor / texture_height,	0, 256 * video_height * height_factor / texture_height};
+	glEnableClientState(GL_VERTEX_ARRAY);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+ 	glVertexPointer(2, GL_FLOAT, 0, vtx1);
+	glTexCoordPointer(2, GL_FLOAT, 0, tex1);
+	glDrawArrays(GL_TRIANGLE_FAN,0,4);
+	glDisableClientState(GL_VERTEX_ARRAY);
+	glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+	}
+#endif
 	glPopMatrix();
 
 	// Make sure the current texture page is reloaded after we are finished
