@@ -28,7 +28,7 @@
 # ifdef WZ_OS_MAC
 #  include <OpenAL/al.h>
 # else
-#  include <AL/al.h>
+#  include "AL/al.h"
 # endif
 #endif
 
