@@ -836,7 +836,7 @@ static BOOL formPickHTab(TAB_POS *psTabPos,
 	// Also need to check if the TabMultiplier is set or not, if not then it means 
 	// we have not yet added the code to display/handle the tab scroll buttons.
 	// At this time, I think only the design screen has this limitation of only 8 tabs.
-	if (number > MAX_TAB_SMALL_SHOWN  && psTabPos->TabMultiplier) // of course only do this if we actually need >8 tabs.
+	if (number > (MAX_TAB_SMALL_SHOWN - 1)  && psTabPos->TabMultiplier) // of course only do this if we actually need >8 tabs.
 	{
 		number -= (psTabPos->TabMultiplier - 1) * TAB_SEVEN;
 		if (number > TAB_SEVEN)	// is it still > than TAB_SEVEN?
@@ -1385,7 +1385,7 @@ static void formDisplayTTabs(W_TABFORM *psForm,SDWORD x0, SDWORD y0,
 	x = x0 + 2;
 	x1 = x + width - 2;
 	y1 = y0 + height;
-	if (number > MAX_TAB_SMALL_SHOWN)	//we can display 8 tabs fine with no extra voodoo.
+	if (number > (MAX_TAB_SMALL_SHOWN - 1))	//we can display 8 tabs fine with no extra voodoo.
 	{	// We do NOT want to draw all the tabs once we have drawn 7 tabs
 		// Both selected & hilite are converted from virtual tab range, to a range
 		// that is seen on the form itself.  This would be 0-6 (7 tabs)
