@@ -609,6 +609,23 @@ BOOL loadRenderMode(void)
 		return false;
 	}
 
+#if defined(PANDORA)
+	// Force fullscreen=true and ColouredCursor=true for the Pandora
+	// as a window would be too small and X cursors interfere with 3D.
+	// Add a setting to set anti-aliasing, values 1, 2 or 4 are valid.
+	setWarzoneKeyNumeric("fullscreen", true);
+	war_setFullscreen(true);
+	setWarzoneKeyNumeric("ColouredCursor", true);
+	war_SetColouredCursor(true);
+
+	if( getWarzoneKeyNumeric("FSAA", &val) ) {
+		war_SetFSAAMode(val);
+	} else {
+		// If no setting set to 1 (no anti-aliasing)
+		setWarzoneKeyNumeric("FSAA", 1);
+		war_SetFSAAMode(1);
+	}
+#else
 	if( getWarzoneKeyNumeric("fullscreen", &val) ) {
 		war_setFullscreen(val);
 	} else {
@@ -623,7 +640,7 @@ BOOL loadRenderMode(void)
 	}
 	else
 	{
-#ifdef WZ_OS_MAC
+#if defined(WZ_OS_MAC)
 		// Mac OS X doesn't support normal cursors
 		war_SetColouredCursor(true);
 		setWarzoneKeyNumeric("ColouredCursor", true);
@@ -632,6 +649,7 @@ BOOL loadRenderMode(void)
 		setWarzoneKeyNumeric("ColouredCursor", false);
 #endif
 	}
+#endif
 
 	if (getWarzoneKeyNumeric("trapCursor", &val))
 	{
@@ -712,6 +730,9 @@ BOOL saveConfig(void)
 	setWarzoneKeyNumeric("height", war_GetHeight());
 	setWarzoneKeyNumeric("bpp", pie_GetVideoBufferDepth());
 	setWarzoneKeyNumeric("fullscreen", war_getFullscreen());
+#ifdef PANDORA
+	setWarzoneKeyNumeric("FSAA", war_GetFSAAMode());
+#endif
 
 	setWarzoneKeyString("language", getLanguage());
 
