@@ -475,6 +475,8 @@ void resetInput(void)
 void processInput(void)
 {
 	BOOL mOverRadar = false;
+	BOOL mOverConstruction = false;
+
 	int WheelZoomIterator;
 
 	if (InGameOpUp || isInGamePopupUp)
@@ -487,6 +489,11 @@ void processInput(void)
 		mOverRadar = true;
 	}
 
+	if(CoordInBuild(mouseX(), mouseY()))
+	{
+		mOverConstruction = true;
+	}
+
 	StartOfLastFrame = currentFrame;
 	currentFrame = frameGetFrameNumber();
 
@@ -509,6 +516,10 @@ void processInput(void)
 		{
 			kf_RadarZoomIn();
 		}
+		else if (mOverConstruction)
+		{
+			kf_BuildPrevPage();
+		}
 		else
 		{
 			for (WheelZoomIterator = 0; WheelZoomIterator < 10; WheelZoomIterator++)
@@ -528,6 +539,10 @@ void processInput(void)
 		{
 			kf_RadarZoomOut();
 		}
+		else if (mOverConstruction)
+		{
+			kf_BuildNextPage();
+		}
 		else
 		{
 			for (WheelZoomIterator = 0; WheelZoomIterator < 10; WheelZoomIterator++)
@@ -2332,6 +2347,7 @@ void	dealWithLMB( void )
 #endif
 		default:
 			ASSERT(!"unknown object position type", "Unknown type from checkMouseLoc" );
+			break;
 	}
 }
 
@@ -2689,6 +2705,7 @@ static void dealWithRMB( void )
 
 				default:
 					ASSERT(!"unknown object position type", "Unknown type from checkMouseLoc");
+					break;
 			}
 		}
 		else
