@@ -25,6 +25,11 @@
  */
 
 #include "lib/framework/frame.h"
+
+#if defined(WZ_OS_WIN)
+#   include <shellapi.h> /* For ShellExecute */
+#endif
+
 #include "lib/framework/input.h"
 #include "lib/ivis_common/rendmode.h"
 #include "lib/sound/mixer.h"
@@ -63,6 +68,9 @@
 // Widget code and non-constant strings do not get along
 static char resolution[WIDG_MAXSTR];
 static char textureSize[WIDG_MAXSTR];
+#ifdef PANDORA
+static char fsaa[WIDG_MAXSTR];
+#endif
 
 tMode titleMode; // the global case
 tMode lastTitleMode; // Since skirmish and multiplayer setup use the same functions, we use this to go back to the corresponding menu.
@@ -104,9 +112,27 @@ static BOOL startTitleMenu(void)
 
 	addSideText(FRONTEND_SIDETEXT, FRONTEND_SIDEX, FRONTEND_SIDEY, _("MAIN MENU"));
 
+	addSmallTextButton(FRONTEND_HYPERLINK, FRONTEND_POS8X, FRONTEND_POS8Y, _("Visit our official site: http://wz2100.net"), 0);
 	return true;
 }
 
+static void runHyperlink(void)
+{
+	if (war_getFullscreen())
+	{
+		SDL_WM_IconifyWindow();
+	}
+#if defined(WZ_OS_WIN)
+	ShellExecuteW(NULL, L"open", L"http://wz2100.net/", NULL, NULL, SW_SHOWNORMAL);
+#elif defined (WZ_OS_MAC)
+	// For the macs
+	system("open http://wz2100.net");
+#else
+	// for linux
+	system("xdg-open http://wz2100.net &");
+#endif
+}
+
 BOOL runTitleMenu(void)
 {
 	UDWORD id;
@@ -133,6 +159,9 @@ BOOL runTitleMenu(void)
 		case FRONTEND_PLAYINTRO:
 			changeTitleMode(SHOWINTRO);
 			break;
+		case FRONTEND_HYPERLINK:
+			runHyperlink();
+			break;
 		default:
 			break;
 	}
@@ -782,6 +811,13 @@ BOOL runAudioOptionsMenu(void)
 // Video Options
 static BOOL startVideoOptionsMenu(void)
 {
+#ifdef PANDORA
+	UDWORD fsaaMode = war_GetFSAAMode();
+	if (fsaaMode == 1)
+		snprintf(fsaa, WIDG_MAXSTR, "Off");
+	else
+		snprintf(fsaa, WIDG_MAXSTR, "%dx", war_GetFSAAMode());
+#endif
 	// Generate the resolution string
 	snprintf(resolution, WIDG_MAXSTR, "%d x %d",
 	         war_GetWidth(), war_GetHeight());
@@ -807,11 +843,16 @@ static BOOL startVideoOptionsMenu(void)
 		addTextButton(FRONTEND_WINDOWMODE_R, FRONTEND_POS2M-55, FRONTEND_POS2Y, _("Windowed"), 0);
 	}
 
+#ifdef PANDORA
+	// FSAA
+	addTextButton(FRONTEND_RESOLUTION, FRONTEND_POS3X-35, FRONTEND_POS3Y, _("FSAA*"), 0);
+	addTextButton(FRONTEND_RESOLUTION_R, FRONTEND_POS3M-55, FRONTEND_POS3Y, fsaa, 0);
+#else
 	// Resolution
 	addTextButton(FRONTEND_RESOLUTION, FRONTEND_POS3X-35, FRONTEND_POS3Y, _("Resolution*"), WBUT_SECONDARY);
 	addTextButton(FRONTEND_RESOLUTION_R, FRONTEND_POS3M-55, FRONTEND_POS3Y, resolution, WBUT_SECONDARY);
 	widgSetString(psWScreen, FRONTEND_RESOLUTION_R, resolution);
-
+#endif
 	// Texture size
 	addTextButton(FRONTEND_TEXTURESZ, FRONTEND_POS4X-35, FRONTEND_POS4Y, _("Texture size"), 0);
 	addTextButton(FRONTEND_TEXTURESZ_R, FRONTEND_POS4M-55, FRONTEND_POS4Y, textureSize, 0);
@@ -846,6 +887,10 @@ BOOL runVideoOptionsMenu(void)
 	{
 		case FRONTEND_WINDOWMODE:
 		case FRONTEND_WINDOWMODE_R:
+#ifdef PANDORA
+			// We don't allow windowed mode on the Pandora,
+			widgSetString(psWScreen, FRONTEND_WINDOWMODE_R, _("Fullscreen (forced)"));
+#else
 			if (war_getFullscreen())
 			{
 				war_setFullscreen(false);
@@ -856,11 +901,34 @@ BOOL runVideoOptionsMenu(void)
 				war_setFullscreen(true);
 				widgSetString(psWScreen, FRONTEND_WINDOWMODE_R, _("Fullscreen"));
 			}
+#endif
 			break;
 
 		case FRONTEND_RESOLUTION:
 		case FRONTEND_RESOLUTION_R:
 		{
+#ifdef PANDORA
+			// Hijacked on Pandora to FSAA
+			UDWORD fsaaMode = war_GetFSAAMode() + 1;
+
+			if (fsaaMode == 5)
+			{
+				fsaaMode = 1;
+				snprintf(fsaa, WIDG_MAXSTR, "Off");
+			}
+			else
+			{
+				if (fsaaMode == 3)
+					fsaaMode = 4;
+				snprintf(fsaa, WIDG_MAXSTR, "%dx", fsaaMode);
+			}
+
+			war_SetFSAAMode(fsaaMode);
+			// Update the widget
+			widgSetString(psWScreen, FRONTEND_RESOLUTION_R, fsaa);
+
+			break;
+#else
 			int current, count, oldcurrent;
 
 			// Get the current mode offset
@@ -903,6 +971,7 @@ BOOL runVideoOptionsMenu(void)
 			widgSetString(psWScreen, FRONTEND_RESOLUTION_R, resolution);
 
 			break;
+#endif
 		}
 
 		case FRONTEND_TRAP:
@@ -1092,6 +1161,10 @@ BOOL runMouseOptionsMenu(void)
 
 		case FRONTEND_CURSORMODE:
 		case FRONTEND_CURSORMODE_R:
+#ifdef PANDORA
+			// Force coloured cursor, Pandora has no HW cursor
+			widgSetString(psWScreen, FRONTEND_CURSORMODE_R, _("On (forced)"));
+#else
 			if (war_GetColouredCursor())
 			{
 				war_SetColouredCursor(false);
@@ -1102,6 +1175,7 @@ BOOL runMouseOptionsMenu(void)
 				war_SetColouredCursor(true);
 				widgSetString(psWScreen, FRONTEND_CURSORMODE_R, _("On"));
 			}
+#endif
 			break;
 
 		case FRONTEND_MBUTTONS:
@@ -1503,6 +1577,10 @@ void displayTextOption(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL
 		{
 			iV_SetTextColour(WZCOL_TEXT_BRIGHT);
 		}
+		else if (psWidget->id == FRONTEND_HYPERLINK)				// special case for our hyperlink
+		{
+			iV_SetTextColour(WZCOL_YELLOW);
+		}
 		else														// dont highlight
 		{
 			iV_SetTextColour(WZCOL_TEXT_MEDIUM);
@@ -1704,6 +1782,49 @@ void addTextButton(UDWORD id,  UDWORD PosX, UDWORD PosY, const char *txt, unsign
 	}
 }
 
+void addSmallTextButton(UDWORD id,  UDWORD PosX, UDWORD PosY, const char *txt, unsigned int style)
+{
+	W_BUTINIT sButInit;
+	memset(&sButInit, 0, sizeof(W_BUTINIT));
+
+	sButInit.formID = FRONTEND_BOTFORM;
+	sButInit.id = id;
+	sButInit.x = (short)PosX;
+	sButInit.y = (short)PosY;
+
+	// Align
+	if ( !(style & WBUT_TXTCENTRE) )
+	{
+		iV_SetFont(font_small);
+		sButInit.width = (short)(iV_GetTextWidth(txt)+10);
+		sButInit.x+=35;
+	}
+	else
+	{
+		sButInit.style |= WBUT_TXTCENTRE;
+		sButInit.width = FRONTEND_BUTWIDTH;
+	}
+
+	// Enable right clicks
+	if (style & WBUT_SECONDARY)
+	{
+		sButInit.style |= WBUT_SECONDARY;
+	}
+
+	sButInit.UserData = (style & WBUT_DISABLE); // store disable state
+
+	sButInit.height = FRONTEND_BUTHEIGHT;
+	sButInit.pDisplay = displayTextOption;
+	sButInit.FontID = font_small;
+	sButInit.pText = txt;
+	widgAddButton(psWScreen, &sButInit);
+
+	// Disable button
+	if (style & WBUT_DISABLE)
+	{
+		widgSetButtonState(psWScreen, id, WBUT_DISABLE);
+	}
+}
 // ////////////////////////////////////////////////////////////////////////////
 void addFESlider(UDWORD id, UDWORD parent, UDWORD x, UDWORD y, UDWORD stops, UDWORD pos)
 {
