@@ -33,6 +33,9 @@
 
 #if defined(WZ_OS_MAC)
 #include <OpenGL/glu.h>
+#elif defined(HAVE_GLES)
+#include <GLES/gl.h>
+#include <GLES/glues.h>
 #else
 #include <GL/glu.h>
 #endif
@@ -102,9 +105,15 @@ static int newPage(const char *name, int level, int width, int height, int count
 
 	pie_SetTexturePage(texPage);
 
+#ifndef HAVE_GLES
 	// Specify first and last mipmap level to be used
 	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_BASE_LEVEL, 0);
 	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAX_LEVEL, mipmap_levels - 1);
+#else
+	// GLES can generate it's own mipmaps. We need this as all levels of mipmap
+	// are required.
+        glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
+#endif
 
 	// debug(LOG_TEXTURE, "newPage: glTexImage2D(page=%d, level=%d) opengl id=%u", texPage, level, _TEX_PAGE[texPage].id);
 	glTexImage2D(GL_TEXTURE_2D, level, wz_texture_compression, width, height, 0,
@@ -193,6 +202,9 @@ bool texLoad(const char *fileName)
 	/* Now load the actual tiles */
 
 	i = mipmap_max; // i is used to keep track of the tile dimensions
+#ifdef HAVE_GLES
+	mipmap_levels = 1;      // No need to load smaller mipmaps, GLES will generate them
+#endif
 	for (j = 0; j < mipmap_levels; j++)
 	{
 		int xOffset = 0, yOffset = 0; // offsets into the texture atlas
@@ -207,7 +219,6 @@ bool texLoad(const char *fileName)
 
 		// Generate the empty texture buffer in VRAM
 		texPage = newPage(fileName, j, xSize, ySize, 0);
-
 		sprintf(partialPath, "%s-%d", fileName, i);
 
 		// Load until we cannot find anymore of them
@@ -259,6 +270,10 @@ bool texLoad(const char *fileName)
 		      k, partialPath, i, texPage, _TEX_PAGE[texPage].id);
 		i /= 2;	// halve the dimensions for the next series; OpenGL mipmaps start with largest at level zero
 	}
+#ifdef HAVE_GLES
+	// Switch off auto generation of mipmaps, only needed for tiles.
+        glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_FALSE);
+#endif
 
 	return true;
 }
