@@ -87,4 +87,9 @@ void war_setSoundEnabled( BOOL soundEnabled );
  */
 BOOL war_getSoundEnabled( void );
 
+#ifdef PANDORA
+UDWORD war_GetFSAAMode( void );
+void war_SetFSAAMode(UDWORD samples);
+#endif
+
 #endif // __INCLUDED_SRC_WARZONECONFIG_H__
